# This file was generated by liblab | https://liblab.com/

from typing import Any
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models import MultipartFile, Poster, PosterEdit, PosterList


class PosterService(BaseService):

    @cast_models
    def list_posters(self, project_id: str, video_id: str) -> PosterList:
        """</br>List all posters associated with a video.

        :param project_id: The ID of the project.
        :type project_id: str
        :param video_id: ID of the video.
        :type video_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: PosterList
        """

        Validator(str).validate(project_id)
        Validator(str).validate(video_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/video/{{video_id}}/poster",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("video_id", video_id)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)
        return PosterList._unmap(response)

    @cast_models
    def upload_poster(
        self, request_body: MultipartFile, project_id: str, video_id: str
    ) -> Poster:
        """</br>Upload a new poster associated with a video. This will not make the poster the default.</br>A video can have a maximum of 20 posters.

        :param request_body: The request body.
        :type request_body: MultipartFile
        :param project_id: The ID of the project.
        :type project_id: str
        :param video_id: ID of the video.
        :type video_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: Poster
        """

        Validator(MultipartFile).validate(request_body)
        Validator(str).validate(project_id)
        Validator(str).validate(video_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/video/{{video_id}}/poster",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("video_id", video_id)
            .serialize()
            .set_method("POST")
            .set_body(request_body, "multipart/form-data")
        )

        response = self.send_request(serialized_request)
        return Poster._unmap(response)

    @cast_models
    def edit_poster(
        self, request_body: PosterEdit, project_id: str, video_id: str, poster_id: str
    ) -> Poster:
        """</br>Edit settings of a poster.

        :param request_body: The request body.
        :type request_body: PosterEdit
        :param project_id: The ID of the project.
        :type project_id: str
        :param video_id: ID of the video.
        :type video_id: str
        :param poster_id: ID of the poster.
        :type poster_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: Poster
        """

        Validator(PosterEdit).validate(request_body)
        Validator(str).validate(project_id)
        Validator(str).validate(video_id)
        Validator(str).validate(poster_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/video/{{video_id}}/poster/{{poster_id}}",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("video_id", video_id)
            .add_path("poster_id", poster_id)
            .serialize()
            .set_method("PUT")
            .set_body(request_body)
        )

        response = self.send_request(serialized_request)
        return Poster._unmap(response)

    @cast_models
    def delete_poster(self, project_id: str, video_id: str, poster_id: str) -> Any:
        """</br>Delete a poster associated with a video by its ID.

        :param project_id: The ID of the project.
        :type project_id: str
        :param video_id: ID of the video.
        :type video_id: str
        :param poster_id: ID of the poster.
        :type poster_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        """

        Validator(str).validate(project_id)
        Validator(str).validate(video_id)
        Validator(str).validate(poster_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/video/{{video_id}}/poster/{{poster_id}}",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("video_id", video_id)
            .add_path("poster_id", poster_id)
            .serialize()
            .set_method("DELETE")
        )

        response = self.send_request(serialized_request)
        return response
