# This file was generated by liblab | https://liblab.com/

from typing import Any
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models import Watermark, WatermarkCreate, WatermarkList


class WatermarkService(BaseService):

    @cast_models
    def list_watermarks(self, project_id: str) -> WatermarkList:
        """</br>Get a list of all available watermarks.

        :param project_id: The ID of the project.
        :type project_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: WatermarkList
        """

        Validator(str).validate(project_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/watermark",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)
        return WatermarkList._unmap(response)

    @cast_models
    def create_watermark(
        self, request_body: WatermarkCreate, project_id: str
    ) -> Watermark:
        """</br>Upload a new watermark. Once it's been uploaded, it can not be updated.

        :param request_body: The request body.
        :type request_body: WatermarkCreate
        :param project_id: The ID of the project.
        :type project_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: Watermark
        """

        Validator(WatermarkCreate).validate(request_body)
        Validator(str).validate(project_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/watermark",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .serialize()
            .set_method("POST")
            .set_body(request_body, "multipart/form-data")
        )

        response = self.send_request(serialized_request)
        return Watermark._unmap(response)

    @cast_models
    def get_watermark(self, project_id: str, watermark_id: str) -> Watermark:
        """</br>Return the details of a single watermark object.

        :param project_id: The ID of the project.
        :type project_id: str
        :param watermark_id: id of the watermark.
        :type watermark_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: Watermark
        """

        Validator(str).validate(project_id)
        Validator(str).validate(watermark_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/watermark/{{watermark_id}}",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("watermark_id", watermark_id)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)
        return Watermark._unmap(response)

    @cast_models
    def delete_watermark(self, project_id: str, watermark_id: str) -> Any:
        """</br>Delete an existing watermark.

        :param project_id: The ID of the project.
        :type project_id: str
        :param watermark_id: id of the watermark.
        :type watermark_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        """

        Validator(str).validate(project_id)
        Validator(str).validate(watermark_id)

        serialized_request = (
            Serializer(
                f"{self.base_url}/api/v1/project/{{project_id}}/watermark/{{watermark_id}}",
                self.get_default_headers(),
            )
            .add_path("project_id", project_id)
            .add_path("watermark_id", watermark_id)
            .serialize()
            .set_method("DELETE")
        )

        response = self.send_request(serialized_request)
        return response
